MAPBOX_ACCESS_TOKEN = 'pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw';

// Create layers
const mapbox = new ol.layer.Tile({
  name: 'mapbox',
  source: new ol.source.XYZ({
    url:'https://api.tiles.mapbox.com/v4/mapbox.light/{z}/{x}/{y}.png?access_token='+MAPBOX_ACCESS_TOKEN
  })
});

// create map
const map = new ol.Map({
  target: 'minimap',
  layers: [mapbox],
  view: new ol.View({
    center: ol.proj.fromLonLat([-99.19, 19.61]),
    zoom: 4,
    minZoom:4
  })
});


// show first date and current date
let currentDate;
if (labels && labels.length > 0) {
  currentDate = labels[0];
  addImageLayer(currentDate)
}


function addImageLayer(labelDate) {
  $.ajax({
    type: 'POST',
    dataType: "json",
    data: {'purchase_id': purchase_id, 'report': zone, 'date': labelDate},
    url: '/reports/tiles/tileinfo',
    success: function (data) {
      const layer_types = getSelectedCheckbox();
      currentDate = labelDate;

      removeImageLayers()

      // add layer
      layer_types.forEach(layer_type => {
        const xyz = new ol.layer.Tile({
          opacity: 1,
          name: layer_type,
          source: new ol.source.XYZ({
            projection: 'EPSG:3857',
            url: '/reports/tiles/'+purchase_id+'/'+zone+'/'+layer_type+'/'+labelDate+'/{z}/{x}/{-y}.png',
            tilePixelRatio: 2,
            minZoom: data.zoom.min,
            maxZoom: data.zoom.max
          })
        });

        map.addLayer(xyz);
      })

      // fit and zoom
      map.getView().fit(ol.proj.transformExtent(data.boundingBox, 'EPSG:4326', 'EPSG:3857'), {duration: 800})
      map.getView().setMinZoom(data.zoom.min);
      map.getView().setMaxZoom(data.zoom.max);
    }
  });
}

function removeImageLayers() {
  var imageLayers = map.getLayers().getArray().slice();
  imageLayers.forEach(layer => {
    if(layer.get('name') != 'mapbox') {
      map.removeLayer(layer)
    }
  })
}

function getSelectedCheckbox() {
  const inputs = $("input[name=layer_type]:checked");
  let values = []

  Object.keys(inputs).forEach(key => {
    let value = inputs[key].value;
    if (value) {values.push(value)}
  })

  return values;
}

$("input[name=layer_type]").on( "click", () => {
  addImageLayer(currentDate);
});
